# 17D Guide

## What is a 17D?

17D is the Army MOS for Officers that are qualified in the Cyber Capability Developer (CCD) workrole. A CCD is a programmer that provides offensive and defensive capabilities for the force. There are three levels of certification: **basic**, **senior**, and **master**. Each level has its own associated JQR (Job Qualification Record) which detail tasks and subtasks on what competencies someone needs to display to become certified. These tasks need to be verified by someone already qualified in the work role level. For example, a basic developer can verify basic tasks. Everyone completes the same basic certification but specialize into a specific discipline at the senior level (see below).

![JQR MAP](_assets/jqr_map.png)


**Anyone, regardless of MOS, can become work role certified**. Either through formal training (17D BOLC or 170D WOBC), mentorship from a developer in the force, or self-study. The only requirement to be awarded the work role is to show competency in every JQR task including passing Basic Skill Level Exam (BSLE) and its associated panel. All of the tasks can be found in [The CCD Basic JQR](_assets/ccd_basic_jqr_v0.0.1.pdf).

**Important Note:** being awarded the work role does not guarantee the 17D MOS or an assignment in a CCD billet. The management of personnel in the MOS is managed by the Office Chief of Cyber (OCC).

## Getting Started

### Curriculum

Course curriculum can be viewed a variety of ways. 

1. **Method 1: Current Students**

    Since the classroom computers are already on the VTA. Simply navigate to [http://ccd.vta/](http://ccd.vta/)

2. **Method 2: Past and Future Students**

    Past student's accounts remain active after graduation and can be used to authenticate to the VTA VPN. Once on the VTA VPN, navigate to [http://10.50.26.80/](http://10.50.26.80/) to view the content.

    If you forgot your password or don't have an account, you can manage your account at [https://register.cybbh.space/](https://register.cybbh.space/) and login using your CAC.

    ??? Note "VPN Guide"

        1. Go to [https://vta.cybbh.io/helpdesk/vpn](https://vta.cybbh.io/helpdesk/vpn)
        2. Download the config file
        3. Launch openvpn with the config file and login
            - on Linux: `sudo openvpn config.ovpn`
            - on Windows: [https://openvpn.net/client/client-connect-vpn-for-windows/](https://openvpn.net/client/client-connect-vpn-for-windows/)
            - on mac: [https://openvpn.net/client-connect-vpn-for-mac-os/](https://openvpn.net/client-connect-vpn-for-mac-os/)

3. **Method 3: Gitlab pages**

    If you have an R2D2 account you can access them at: [https://ccds.pages.levelup.cce.af.mil/training/basic/curriculum/](https://ccds.pages.levelup.cce.af.mil/training/basic/curriculum/)
    
4. **Method 4: Building from Source**

    If you already have an R2D2 account you can build the lessons from source at: [https://code.levelup.cce.af.mil/ccds/training/basic/curriculum](https://code.levelup.cce.af.mil/ccds/training/basic/curriculum)

### Projects 

#### Access

All CCD curriculum and projects are managed as code in a gitlab instance we refer to as “R2D2” (Required Replacement for Devforce and DI2E). Getting an R2D2 account is required in order to complete the large projects that serve as major milestones in the course. To request access:

- Go to [https://fams.cce.af.mil/](https://fams.cce.af.mil/)
- login with your CAC
- fill in your profile information and personal/organizational details
- Choose System Authorization Request (SAAR):
    - Choose JCWA
    - Choose "NO" for JAWS
    - Choose “CCD“ for Team Key with "Viewer" rights
    - Justification: "R2D2 Gitlab access required to complete CCD JQR training"
- Select "Submit"

#### Instancing

Any basic qualified developer is able to create projects for developer candidates when they hit the major milestones of the course. Simply ask them to generate the applicable project with your r2d2 username [at this pipeline](https://code.levelup.cce.af.mil/ccds/training/basic/instructor/project-generator/-/pipelines/new)


### Content Consumption:

- There is a “17D Syllabus” on the site that can be used as a guide that has links to all lessons, the order to consume the content, and the time it should take to complete. Please contact your local developer cell or mentor to create projects for you when you have reached the major milestones.
- Read the relevant lessons on the site.
- Do the practical exercises.
- Complete the projects at the major milestones.

## Your JQR Repository

All developers have a repository that tracks their progress on JQR completion. Once you have R2D2 Access you can create one [by running this pipeline](https://code.levelup.cce.af.mil/uscc-work-role-jqs/ccd-basic-dev/-/pipelines/new)

This repository will stay with you as you grow as a Cyberspace Capabilities Developer. Once created you will find each JQR Item as an issue for this project. To certify on a task:
1. Create a branch from the issue
2. Commit relevant code to the branch
3. Submit a merge request to `main` and tag your mentor as a reviewer, ensure to use the verbiage `closes #xx` where "xx" is the issue number.

Your mentor will conduct a code review and provide feedback. Once an instructor/mentor has blessed off on the submission, a certified developer will merge the request, signing off on the submission and closing the issue. See README.md in the repository for more details. Once all issues are completed the student will be afforded the opportunity to take the BSLE.

## BSLE

The Basic Skill Level Exam is a 10-day exam that evaluates all the tasks in the basic JQR in the form of a single large project. The exam is an individual effort with no direct help allowed. A proctor is provided if clarifications in directions are required. Due to the sensitive nature of the exam any further details will be provided during the taking of the exam. Following the coding portion of the BSLE is the board portion. The board will have at minimum 3 members (one of which a senior developer) who will talk with the CCD candidate about their code, design choices, and discuss flaws in its execution or style. Once the board convenes, a recommendation of pass or fail is submitted, and the candidate is notified of the result. If a candidate fails the BSLE, there is typically a required cooldown period before a second attempt can be made. The length of the cooldown period varies depending on the candidate's performance.

## Suggested Resources

- [oreilly.com](https://www.oreilly.com/): Textbooks for any programming subject. Use your army.mil for free access to all of the ebooks.
- [digitalu.udemy.com](https://digitalu.udemy.com): Free access to ANY udemy.com course, use CAC SSO for sign in.
- [Beej’s guides](https://beej.us/guide/): Networking one is especially useful.
- ["The C Programming Language 2nd edition" by Kernighan and Ritchie](https://www.oreilly.com/library/view/c-programming-language/9780133086249/): Explains how C works at a very basic and introductory level.
- ["The Linux Programming Interface" by Kerrisk](https://www.oreilly.com/library/view/the-linux-programming/9781593272203/): Every linux system call, how it works, and any nuances to account for.
- ["Operating Systems: Three Easy Pieces"](https://pages.cs.wisc.edu/~remzi/OSTEP/): How OS works.
- [Embedded C Coding standard](https://barrgroup.com/sites/default/files/barr_c_coding_standard_2018.pdf): The barr-c styleguide. The ability to follow a styleguide is an important measure of how ready someone is to join a team.

For questions, please contact the schoolhouse 17D section located in the CTED across from CTB HQ&A on Barnes Ave.
